@@ -41,7 +41,7 @@
 
 #  include <ndbm.h>
 
-#  define P_DBM DBM
+#  define P_DB DBM
 #  define P_DBT datum
 
 #  define p_dptr dptr
@@ -49,7 +49,7 @@
 
 #  define p_dbopen(a) dbm_open (a, O_CREAT|O_RDWR, 0600)
 #  define p_dbclose(a) dbm_close (a)
-#  define p_dbput(a,b,c) dbm_store(a, *(b), *(c))
+#  define p_dbput(a,b,c) dbm_store(a, *(b), *(c), DBM_REPLACE)
 
 
 int p_dbget (P_DBM *dbm, P_DBT *key, P_DBT *dat);
