@@ -1,6 +1,6 @@
 #include "p_db.h"
 
-int p_dbget (P_DBM *dbm, P_DBT *key, P_DBT *dat)
+int p_dbget (P_DB *dbm, P_DBT *key, P_DBT *dat)
 {
   *dat = dbm_fetch (dbm, *key);
   return dat->dptr ? 0 : 1;
